//+------------------------------------------------------------------+
//|                                      Elliott Wave Oscillator.mq4 |
//|                                                tonyc2a@yahoo.com |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "tonyc2a@yahoo.com"
#property link      ""

#property indicator_separate_window
#property indicator_buffers 3
#property indicator_color1 LimeGreen
#property indicator_color2 Orange
#property indicator_color3 Orange
#property indicator_width1 2
#property indicator_width2 2
#property indicator_width3 2
//---- input parameters
extern int    EWOPeriod1      = 5;
extern int    EWOPeriod2      = 35;
extern bool   alertsOn        = true;
extern bool   alertsOnCurrent = true;
extern bool   alertsMessage   = true;
extern bool   alertsSound     = false;
extern bool   alertsNotify    = true;
extern bool   alertsEmail     = true;
extern string soundFile       = "alert2.wav"; 

//---- buffers
double Buffer1[];
double Buffer2[];
double Buffer3[];
double slope[];

//-------------------------------------------------------------------
//
//-------------------------------------------------------------------
//
//

int init()
{
   IndicatorBuffers(4);
   SetIndexBuffer(0, Buffer1); SetIndexLabel(0, "EWO");
   SetIndexBuffer(1, Buffer2); SetIndexLabel(1, "EWO");
   SetIndexBuffer(2, Buffer3); SetIndexLabel(2, "EWO");
   SetIndexBuffer(3, slope);
   IndicatorShortName("EWO(" + EWOPeriod1 + ", " + EWOPeriod2 + ")");
   return(0);
}
int deinit(){   return(0);  }
  
//-------------------------------------------------------------------
//
//-------------------------------------------------------------------
//
//

int start()
  {
   int counted_bars=IndicatorCounted();
      if(counted_bars<0) return(-1);
      if(counted_bars>0) counted_bars--;
         int limit = MathMin(Bars-counted_bars,Bars-1);
   
   //
   //
   //
   //
   //
   
   if (slope[limit]==-1) CleanPoint(limit,Buffer2,Buffer3);
   for(int i=limit; i >= 0; i--)
     {
       double MA1 = iMA(NULL, 0, EWOPeriod1, 0, MODE_SMA, PRICE_MEDIAN, i);
       double MA2 = iMA(NULL, 0, EWOPeriod2, 0, MODE_SMA, PRICE_MEDIAN, i);
       Buffer1[i] = MA1-MA2;
       Buffer2[i] = EMPTY_VALUE;
       Buffer3[i] = EMPTY_VALUE;
       slope[i]   = slope[i+1];
         if (Buffer1[i]>Buffer1[i+1]) slope[i] =  1;
         if (Buffer1[i]<Buffer1[i+1]) slope[i] = -1;
         if (slope[i]==-1) PlotPoint(i,Buffer2,Buffer3,Buffer1);
     }
     
     //
     //
     //
     //
     //
     
     if (alertsOn)
     {
        if (alertsOnCurrent)
             int whichBar = 0;
        else     whichBar = 1;
        if (slope[whichBar] != slope[whichBar+1])
        if (slope[whichBar] == 1)
              doAlert("Buy");
        else  doAlert("Sell");       
     }
return(0);
}

//-------------------------------------------------------------------
//
//-------------------------------------------------------------------
//
//
//
//
//

void CleanPoint(int i,double& first[],double& second[])
{
   if (i>Bars-2) return;
   if ((second[i]  != EMPTY_VALUE) && (second[i+1] != EMPTY_VALUE))
        second[i+1] = EMPTY_VALUE;
   else
      if ((first[i] != EMPTY_VALUE) && (first[i+1] != EMPTY_VALUE) && (first[i+2] == EMPTY_VALUE))
          first[i+1] = EMPTY_VALUE;
}

//
//
//
//
//

void PlotPoint(int i,double& first[],double& second[],double& from[])
{
   if (i>Bars-3) return;
   if (first[i+1] == EMPTY_VALUE)
      {
         if (first[i+2] == EMPTY_VALUE) {
                first[i]   = from[i];
                first[i+1] = from[i+1];
                second[i]  = EMPTY_VALUE;
            }
         else {
                second[i]   =  from[i];
                second[i+1] =  from[i+1];
                first[i]    = EMPTY_VALUE;
            }
      }
   else
      {
         first[i]  = from[i];
         second[i] = EMPTY_VALUE;
      }
}

//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," EWO ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsNotify)  SendNotification(StringConcatenate(Symbol(), Period() ," EWO " +" "+message));
             if (alertsEmail)   SendMail(StringConcatenate(Symbol()," EWO "),message);
             if (alertsSound)   PlaySound(soundFile);
      }
}